==> prestashop_1.5.0.17.zip: prestashop/modules/blockcms/translations/de.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{blockcms}prestashop>blockcms_cd275312651aebf8cbbb8d3bb1c086ae'] = 'CMS-Block';
$_MODULE['<{blockcms}prestashop>blockcms_cdca12007979fc49008fd125cdb775fc'] = 'Fügt einen Block mit mehreren CMS-Links hinzu';
$_MODULE['<{blockcms}prestashop>blockcms_a82be0f551b8708bc08eb33cd9ded0cf'] = 'Information';
$_MODULE['<{blockcms}prestashop>blockcms_ea4788705e6873b424c65e91c2846b19'] = 'Abbrechen';
$_MODULE['<{blockcms}prestashop>blockcms_ef61fb324d729c341ea8ab9901e23566'] = 'Neu';
$_MODULE['<{blockcms}prestashop>blockcms_c9cc8cce247e49bae79f15173ce97354'] = 'Speichern';
$_MODULE['<{blockcms}prestashop>blockcms_97390dd0b5ba7867120aee2ff22bfa38'] = 'CMS-Block-Konfiguration';
$_MODULE['<{blockcms}prestashop>blockcms_94ff014237f6f5cbf5c3655f5ef513c9'] = 'CMS Blöcke:';
$_MODULE['<{blockcms}prestashop>blockcms_965be994da393e5aa15bd3a2444c6ccf'] = 'Konfiguration verschiedener Links in der Fußzeile';
$_MODULE['<{blockcms}prestashop>blockcms_89887a6d62110cbd72c15218a2d0fda9'] = 'Verschiedene Links und Informationen in der Fußzeile anzeigen';
$_MODULE['<{blockcms}prestashop>blockcms_48566f492af8fd2346b20dbd32168476'] = 'Footer Links:';
$_MODULE['<{blockcms}prestashop>blockcms_0b31e765f1e9cb451319b32e84a75a9e'] = 'Alle Seiten markieren welche in dem Footer CMS Block angezeigt werden sollen';
$_MODULE['<{blockcms}prestashop>blockcms_6c5f7d2f911e91ebd0c077fe770e739e'] = 'Informationen in der Fußzeile';
$_MODULE['<{blockcms}prestashop>blockcms_32c532e462a1f85b1b103ed9989a1aba'] = 'Display \"Powered by PrestaShop\"';
$_MODULE['<{blockcms}prestashop>blockcms_38fb7d24e0d60a048f540ecb18e13376'] = 'Speichern';
$_MODULE['<{blockcms}prestashop>blockcms_be58fccb15fb119b8c3d485e3a8561c4'] = 'CMS-Block-Konfiguration';
$_MODULE['<{blockcms}prestashop>blockcms_e83c1afa1d3dbe19fa9becebb5ca8480'] = 'CMS-Block bearbeiten';
$_MODULE['<{blockcms}prestashop>blockcms_5aa1602194579edb6f91d7dd53eadb32'] = 'CMS-Block hinzufügen';
$_MODULE['<{blockcms}prestashop>blockcms_ab278feec882a679b078490639232d69'] = 'Blockname';
$_MODULE['<{blockcms}prestashop>blockcms_bdbaef442c586e1bbecb44eba1ba7e2d'] = 'Wenn Sie dieses Feld leer lassen, übernimmt der Blockname den Kategorienamen';
$_MODULE['<{blockcms}prestashop>blockcms_fca0206c8afc8d67969f9aec20e3287e'] = 'Kategorie CMS';
$_MODULE['<{blockcms}prestashop>blockcms_abf9012e9560b3c44a536f5c4a2a0b62'] = 'Lager';
$_MODULE['<{blockcms}prestashop>blockcms_945d5e233cf7d6240f6b783b36a374ff'] = 'Links';
$_MODULE['<{blockcms}prestashop>blockcms_92b09c7c48c520c3c55e497875da437c'] = 'Rechts';
$_MODULE['<{blockcms}prestashop>blockcms_5e2b11203c9a4ac0ec01e7bb31e256f6'] = 'Shops anzeigen';
$_MODULE['<{blockcms}prestashop>blockcms_93cba07454f06a4a960172bbd6e2a435'] = 'Ja';
$_MODULE['<{blockcms}prestashop>blockcms_bafd7322c6e97d25b6299b5d6fe8920b'] = 'Nein';
$_MODULE['<{blockcms}prestashop>blockcms_08f3899ad165f85f8596199966b8c673'] = '\"Unsere Shops\" anzeigen am Ende des Blocks';
$_MODULE['<{blockcms}prestashop>blockcms_55737e084beaa370a127f3f031f1932e'] = 'CMS Inhalt:';
$_MODULE['<{blockcms}prestashop>blockcms_4d388b3442c6b155f0613fda97b1369a'] = 'Alle Seiten markieren welche in diesem Block angezeigt werden sollen';
$_MODULE['<{blockcms}prestashop>blockcms_3cd97b7a82d531d009884f9633a007cc'] = 'Ungültiger Shop-Darstellungswert';
$_MODULE['<{blockcms}prestashop>blockcms_903d12e7aa8c380c290b78c1898e01b7'] = 'Ungültige Block-Position';
$_MODULE['<{blockcms}prestashop>blockcms_92fc29650a0f9dd3fca4e5de1845f78b'] = 'Sie müssen mindestens eine Seite oder Unterkategorie wählen, um einen CMS-Block zu erstellen';
$_MODULE['<{blockcms}prestashop>blockcms_5e75cbfbfd02a7b2fab0ed21505e811b'] = 'Ungültige CMS-Seite oder Kategorie';
$_MODULE['<{blockcms}prestashop>blockcms_420d575844f77db5299065080d9c237f'] = 'Blockname ist zu lang';
$_MODULE['<{blockcms}prestashop>blockcms_ede67d50014846cb8bb1b00d5fde77be'] = 'id_cms_block ist ungültig';
$_MODULE['<{blockcms}prestashop>blockcms_7ab6862bda9343553ef49bffb7a4f73c'] = 'Bitte Footer-Text für die Standardsprache angeben';
$_MODULE['<{blockcms}prestashop>blockcms_05b51791a83d3cef29ad68b70d48d131'] = 'Ungültige Aktivierung Fußzeile';
$_MODULE['<{blockcms}prestashop>blockcms_467efc7b3308cc86cd3e142be9be2189'] = 'Neuer Block kann nicht erstellt werden!';
$_MODULE['<{blockcms}prestashop>blockcms_5dab5acc3c6a2a7e87e8d8926a2c763e'] = 'Versucht einen nicht vorhandenen CMS-Block zu löschen';
$_MODULE['<{blockcms}prestashop>blockcms_963b266405940fb5063673d6c1d6f262'] = 'Die Informationen der Fusszeile sind aktualisiert worden.';
$_MODULE['<{blockcms}prestashop>blockcms_ddd7d8a072783afaf23e5e6843398fc9'] = 'CMS-Block erfolgreich hinzugefügt';
$_MODULE['<{blockcms}prestashop>blockcms_31a22821c66edf7e3aa33ef1c8109f4c'] = 'CMS-Block erfolgreich bearbeitet';
$_MODULE['<{blockcms}prestashop>blockcms_87a2663d841b78f01c27c0edb4f50b76'] = 'Löschen erfolgreich';
$_MODULE['<{blockcms}prestashop>blockcms_34c869c542dee932ef8cd96d2f91cae6'] = 'Unsere Shops';
$_MODULE['<{blockcms}prestashop>blockcms_d1aa22a3126f04664e0fe3f598994014'] = 'Specials';
$_MODULE['<{blockcms}prestashop>blockcms_9ff0635f5737513b1a6f559ac2bff745'] = 'Neue Produkte';
$_MODULE['<{blockcms}prestashop>blockcms_3cb29f0ccc5fd220a97df89dafe46290'] = 'Verkaufshits';
$_MODULE['<{blockcms}prestashop>blockcms_02d4482d332e1aef3437cd61c9bcc624'] = 'Kontaktieren Sie uns';
$_MODULE['<{blockcms}prestashop>blockcms_7a52e36bf4a1caa031c75a742fb9927a'] = 'Powered by';
$_MODULE['<{blockcms}prestashop>form_4dabfa54822012dfc78d6ef40f224173'] = 'Blöcke links';
$_MODULE['<{blockcms}prestashop>form_d9ca3009e18447d91cd2e324e8e680ce'] = 'Blöcke rechts';
$_MODULE['<{blockcms}prestashop>form_b718adec73e04ce3ec720dd11a06a308'] = 'ID';
$_MODULE['<{blockcms}prestashop>form_aae551ce0c29dfe39b0ff20139abdef3'] = 'Blockname';
$_MODULE['<{blockcms}prestashop>form_bb34a159a88035cce7ef1607e7907f8f'] = 'Name der Kategorie';
$_MODULE['<{blockcms}prestashop>form_52f5e0bc3859bc5f5e25130b6c7e8881'] = 'Position';
$_MODULE['<{blockcms}prestashop>form_06df33001c1d7187fdd81ea1f5b277aa'] = 'Handlungen';
$_MODULE['<{blockcms}prestashop>form_08a38277b0309070706f6652eeae9a53'] = 'runter';
$_MODULE['<{blockcms}prestashop>form_258f49887ef8d14ac268c92b02503aaa'] = 'rauf';
$_MODULE['<{blockcms}prestashop>form_7dce122004969d56ae2e0245cb754d35'] = 'Bearbeiten';
$_MODULE['<{blockcms}prestashop>form_f2a6c498fb90ee345d997f888fce3b18'] = 'Löschen';
$_MODULE['<{blockcms}prestashop>form_49ee3087348e8d44e1feda1917443987'] = 'Name';
$_MODULE['<{blockcms}prestashop>form_288af9ab7bf1ea82c86597d0adc2de31'] = 'Keine Seite angelegt';

==> prestashop_1.5.3.1.zip: prestashop/modules/blockcms/translations/de.php <==
<?php

global $_MODULE;
$_MODULE = array();

$_MODULE['<{blockcms}prestashop>blockcms_cd275312651aebf8cbbb8d3bb1c086ae'] = 'CMS-Block';
$_MODULE['<{blockcms}prestashop>blockcms_cdca12007979fc49008fd125cdb775fc'] = 'Fügt einen Block mit mehreren CMS-Links hinzu';
$_MODULE['<{blockcms}prestashop>blockcms_97390dd0b5ba7867120aee2ff22bfa38'] = 'CMS-Block-Konfiguration';
$_MODULE['<{blockcms}prestashop>blockcms_94ff014237f6f5cbf5c3655f5ef513c9'] = 'CMS Blöcke:';
$_MODULE['<{blockcms}prestashop>blockcms_bdbaef442c586e1bbecb44eba1ba7e2d'] = 'Wenn Sie dieses Feld leer lassen, übernimmt der Blockname den Kategorienamen';
$_MODULE['<{blockcms}prestashop>blockcms_fca0206c8afc8d67969f9aec20e3287e'] = 'Kategorie CMS';
$_MODULE['<{blockcms}prestashop>blockcms_abf9012e9560b3c44a536f5c4a2a0b62'] = 'Lager';
$_MODULE['<{blockcms}prestashop>blockcms_945d5e233cf7d6240f6b783b36a374ff'] = 'Links';
$_MODULE['<{blockcms}prestashop>blockcms_5e2b11203c9a4ac0ec01e7bb31e256f6'] = 'Shops anzeigen';
$_MODULE['<{blockcms}prestashop>blockcms_bafd7322c6e97d25b6299b5d6fe8920b'] = 'Nein';
$_MODULE['<{blockcms}prestashop>blockcms_08f3899ad165f85f8596199966b8c673'] = '\\"Unsere Shops\\" anzeigen am Ende des Blocks';
$_MODULE['<{blockcms}prestashop>blockcms_55737e084beaa370a127f3f031f1932e'] = 'CMS Inhalt:';
$_MODULE['<{blockcms}prestashop>blockcms_420d575844f77db5299065080d9c237f'] = 'Blockname ist zu lang';
$_MODULE['<{blockcms}prestashop>blockcms_05b51791a83d3cef29ad68b70d48d131'] = 'Ungültige Aktivierung Fußzeile';
$_MODULE['<{blockcms}prestashop>blockcms_5dab5acc3c6a2a7e87e8d8926a2c763e'] = 'Versucht einen nicht vorhandenen CMS-Block zu löschen';
$_MODULE['<{blockcms}prestashop>blockcms_ddd7d8a072783afaf23e5e6843398fc9'] = 'CMS-Block erfolgreich hinzugefügt';
$_MODULE['<{blockcms}prestashop>form_b718adec73e04ce3ec720dd11a06a308'] = 'ID';
$_MODULE['<{blockcms}prestashop>form_aae551ce0c29dfe39b0ff20139abdef3'] = 'Blockname';
$_MODULE['<{blockcms}prestashop>form_bb34a159a88035cce7ef1607e7907f8f'] = 'Name der Kategorie';
$_MODULE['<{blockcms}prestashop>form_08a38277b0309070706f6652eeae9a53'] = 'runter';
$_MODULE['<{blockcms}prestashop>form_288af9ab7bf1ea82c86597d0adc2de31'] = 'Keine Seite angelegt';
$_MODULE['<{blockcms}prestashop>blockcms_e1da49db34b0bdfdddaba2ad6552f848'] = 'Sitemap';
$_MODULE['<{blockcms}prestashop>blockcms_a82be0f551b8708bc08eb33cd9ded0cf'] = 'Information';
$_MODULE['<{blockcms}prestashop>blockcms_ef61fb324d729c341ea8ab9901e23566'] = 'Neu';
$_MODULE['<{blockcms}prestashop>blockcms_c9cc8cce247e49bae79f15173ce97354'] = 'Speichern';
$_MODULE['<{blockcms}prestashop>blockcms_965be994da393e5aa15bd3a2444c6ccf'] = 'Konfiguration verschiedener Links in der Fußzeile';
$_MODULE['<{blockcms}prestashop>blockcms_32c532e462a1f85b1b103ed9989a1aba'] = 'Display \\"Powered by PrestaShop\\"';
$_MODULE['<{blockcms}prestashop>blockcms_be58fccb15fb119b8c3d485e3a8561c4'] = 'CMS-Block-Konfiguration';
$_MODULE['<{blockcms}prestashop>blockcms_5aa1602194579edb6f91d7dd53eadb32'] = 'CMS-Block hinzufügen';
$_MODULE['<{blockcms}prestashop>blockcms_ab278feec882a679b078490639232d69'] = 'Blockname';
$_MODULE['<{blockcms}prestashop>blockcms_93cba07454f06a4a960172bbd6e2a435'] = 'Ja';
$_MODULE['<{blockcms}prestashop>blockcms_903d12e7aa8c380c290b78c1898e01b7'] = 'Ungültige Block-Position';
$_MODULE['<{blockcms}prestashop>blockcms_92fc29650a0f9dd3fca4e5de1845f78b'] = 'Sie müssen mindestens eine Seite oder Unterkategorie wählen, um einen CMS-Block zu erstellen';
$_MODULE['<{blockcms}prestashop>blockcms_34c869c542dee932ef8cd96d2f91cae6'] = 'Unsere Shops';
$_MODULE['<{blockcms}prestashop>blockcms_d1aa22a3126f04664e0fe3f598994014'] = 'Specials';
$_MODULE['<{blockcms}prestashop>blockcms_02d4482d332e1aef3437cd61c9bcc624'] = 'Kontaktieren Sie uns';
$_MODULE['<{blockcms}prestashop>form_d9ca3009e18447d91cd2e324e8e680ce'] = 'Blöcke rechts';
$_MODULE['<{blockcms}prestashop>form_52f5e0bc3859bc5f5e25130b6c7e8881'] = 'Position';
$_MODULE['<{blockcms}prestashop>form_258f49887ef8d14ac268c92b02503aaa'] = 'rauf';
$_MODULE['<{blockcms}prestashop>form_7dce122004969d56ae2e0245cb754d35'] = 'Bearbeiten';
$_MODULE['<{blockcms}prestashop>form_49ee3087348e8d44e1feda1917443987'] = 'Name';
$_MODULE['<{blockcms}prestashop>blockcms_89887a6d62110cbd72c15218a2d0fda9'] = 'Verschiedene Links und Informationen in der Fußzeile anzeigen';
$_MODULE['<{blockcms}prestashop>blockcms_0b31e765f1e9cb451319b32e84a75a9e'] = 'Alle Seiten markieren welche in dem Footer CMS Block angezeigt werden sollen';
$_MODULE['<{blockcms}prestashop>blockcms_6c5f7d2f911e91ebd0c077fe770e739e'] = 'Informationen in der Fußzeile';
$_MODULE['<{blockcms}prestashop>blockcms_4d388b3442c6b155f0613fda97b1369a'] = 'Alle Seiten markieren welche in diesem Block angezeigt werden sollen';
$_MODULE['<{blockcms}prestashop>blockcms_5e75cbfbfd02a7b2fab0ed21505e811b'] = 'Ungültige CMS-Seite oder Kategorie';
$_MODULE['<{blockcms}prestashop>blockcms_ede67d50014846cb8bb1b00d5fde77be'] = 'id_cms_block ist ungültig';
$_MODULE['<{blockcms}prestashop>blockcms_7ab6862bda9343553ef49bffb7a4f73c'] = 'Bitte Footer-Text für die Standardsprache angeben';
$_MODULE['<{blockcms}prestashop>blockcms_963b266405940fb5063673d6c1d6f262'] = 'Die Informationen der Fusszeile sind aktualisiert worden.';
$_MODULE['<{blockcms}prestashop>blockcms_87a2663d841b78f01c27c0edb4f50b76'] = 'Löschen erfolgreich';
$_MODULE['<{blockcms}prestashop>blockcms_9ff0635f5737513b1a6f559ac2bff745'] = 'Neue Produkte';
$_MODULE['<{blockcms}prestashop>blockcms_3cb29f0ccc5fd220a97df89dafe46290'] = 'Verkaufshits';
$_MODULE['<{blockcms}prestashop>blockcms_5813ce0ec7196c492c97596718f71969'] = 'Sitemap';
$_MODULE['<{blockcms}prestashop>blockcms_ea4788705e6873b424c65e91c2846b19'] = 'Abbrechen';
$_MODULE['<{blockcms}prestashop>blockcms_48566f492af8fd2346b20dbd32168476'] = 'Footer Links:';
$_MODULE['<{blockcms}prestashop>blockcms_38fb7d24e0d60a048f540ecb18e13376'] = 'Speichern';
$_MODULE['<{blockcms}prestashop>blockcms_e83c1afa1d3dbe19fa9becebb5ca8480'] = 'CMS-Block bearbeiten';
$_MODULE['<{blockcms}prestashop>blockcms_92b09c7c48c520c3c55e497875da437c'] = 'Rechts';
$_MODULE['<{blockcms}prestashop>blockcms_3cd97b7a82d531d009884f9633a007cc'] = 'Ungültiger Shop-Darstellungswert';
$_MODULE['<{blockcms}prestashop>blockcms_467efc7b3308cc86cd3e142be9be2189'] = 'Neuer Block kann nicht erstellt werden!';
$_MODULE['<{blockcms}prestashop>blockcms_31a22821c66edf7e3aa33ef1c8109f4c'] = 'CMS-Block erfolgreich bearbeitet';
$_MODULE['<{blockcms}prestashop>blockcms_7a52e36bf4a1caa031c75a742fb9927a'] = 'Powered by';
$_MODULE['<{blockcms}prestashop>form_4dabfa54822012dfc78d6ef40f224173'] = 'Blöcke links';
$_MODULE['<{blockcms}prestashop>form_06df33001c1d7187fdd81ea1f5b277aa'] = 'Handlungen';
$_MODULE['<{blockcms}prestashop>form_f2a6c498fb90ee345d997f888fce3b18'] = 'Löschen';
